class Bozohttpd < Formula
  desc "Small and secure http version 1.1 server"
  homepage "https://pkgsrc.se/www/bozohttpd"
  url "https://cdn.netbsd.org/pub/pkgsrc/distfiles/LOCAL_PORTS/bozohttpd-20240126.tar.bz2"
  sha256 "576267bc5681c52b650294c3f2a85b8c8d8c239e75e71aaba7973771f852b56d"
  license "BSD-2-Clause"

  depends_on "pkg-config" => :build
  depends_on "lua"
  depends_on "openssl@3"

  def install
    # Both `cflags` are explained at http://www.eterna.com.au/bozohttpd/bozohttpd.8.html
    cflags = [
      # Disable NetBSD blocklistd support, which is enabled by default (see section "BLOCKLIST SUPPORT")
      "-DNO_BLOCKLIST_SUPPORT",
      # Enable basic authentication, which is disabled by default (see section "HTTP BASIC AUTHORIZATION")
      "-DDO_HTPASSWD",
    ]
    cflags << Utils.safe_popen_read("pkg-config", "--libs", "--cflags", "lua").chomp
    cflags << Utils.safe_popen_read("pkg-config", "--libs", "--cflags", "libcrypto").chomp

    ENV.append "CFLAGS", cflags.join(" ")
    system "make", "-f", "Makefile.boot", "CC=#{ENV.cc}"
    bin.install "bozohttpd"
  end

  test do
    port = free_port

    expected_output = "Hello from bozotic httpd!"
    (testpath/"index.html").write expected_output

    fork do
      exec bin/"bozohttpd", "-b", "-f", "-I", port.to_s, testpath
    end
    sleep 3

    assert_match expected_output, shell_output("curl -s 127.0.0.1:#{port}")
  end
end
